summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/association.h
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/association.h')
-rw-r--r--umbrello/umbrello/association.h30
1 files changed, 15 insertions, 15 deletions
diff --git a/umbrello/umbrello/association.h b/umbrello/umbrello/association.h
index 3b0ef94d..01fb357e 100644
--- a/umbrello/umbrello/association.h
+++ b/umbrello/umbrello/association.h
@@ -12,7 +12,7 @@
#ifndef ASSOCIATION_H
#define ASSOCIATION_H
-#include <qdom.h>
+#include <tqdom.h>
#include "umlnamespace.h"
#include "umlobject.h"
@@ -66,7 +66,7 @@ public:
/**
* Returns a String representation of this UMLAssociation.
*/
- QString toString( ) const;
+ TQString toString( ) const;
/**
* Converts a Uml::Association_Type to its string representation.
@@ -74,7 +74,7 @@ public:
* @param atype The Association_Type enum value to convert.
* @return The string representation of the Association_Type.
*/
- static QString typeAsString(Uml::Association_Type atype);
+ static TQString typeAsString(Uml::Association_Type atype);
/**
* Returns true if the given Association_Type has a representation as a
@@ -131,21 +131,21 @@ public:
*
* @return The multiplicity assigned to the given role.
*/
- QString getMulti(Uml::Role_Type role) const;
+ TQString getMulti(Uml::Role_Type role) const;
/**
* Returns the name assigned to the role A.
*
* @return The name assigned to the given role.
*/
- QString getRoleName(Uml::Role_Type role) const;
+ TQString getRoleName(Uml::Role_Type role) const;
/**
* Returns the documentation assigned to the given role.
*
* @return Documentation text of given role.
*/
- QString getRoleDoc(Uml::Role_Type role) const;
+ TQString getRoleDoc(Uml::Role_Type role) const;
/**
* Sets the assocType of the UMLAssociation.
@@ -184,7 +184,7 @@ public:
* @param multi The multiplicity of the given role.
* @param role The Uml::Role_Type to which the multiplicity is being applied
*/
- void setMulti(const QString &multi, Uml::Role_Type role);
+ void setMulti(const TQString &multi, Uml::Role_Type role);
/**
* Sets the name of the given role of the UMLAssociation.
@@ -192,7 +192,7 @@ public:
* @param roleName The name to set for the given role.
* @param role The Uml::Role_Type for which to set the name.
*/
- void setRoleName(const QString &roleName, Uml::Role_Type role);
+ void setRoleName(const TQString &roleName, Uml::Role_Type role);
/**
* Sets the documentation on the given role in the association.
@@ -200,14 +200,14 @@ public:
* @param doc The string with the documentation.
* @param role The Uml::Role_Type to which the documentation is being applied
*/
- void setRoleDoc(const QString &doc, Uml::Role_Type role);
+ void setRoleDoc(const TQString &doc, Uml::Role_Type role);
/**
* Convert Changeability_Type value into QString representation.
*
* @param type The Changeability_Type enum value to convert.
*/
- static QString ChangeabilityToString(Uml::Changeability_Type type);
+ static TQString ChangeabilityToString(Uml::Changeability_Type type);
/**
* Get the underlying UMLRole object for the given role.
@@ -248,14 +248,14 @@ public:
* Creates the <UML:Generalization> or <UML:Association> XMI element
* including its role objects.
*/
- void saveToXMI(QDomDocument& qDoc, QDomElement& qElement);
+ void saveToXMI(TQDomDocument& qDoc, TQDomElement& qElement);
protected:
/**
* Creates the <UML:Generalization> or <UML:Association> XMI element
* including its role objects.
*/
- bool load(QDomElement& element);
+ bool load(TQDomElement& element);
// keep track of number of parent widgets
int nrof_parent_widgets;
@@ -278,12 +278,12 @@ protected:
static const Uml::Association_Type atypeFirst;
static const Uml::Association_Type atypeLast;
static const unsigned int nAssocTypes;
- static const QString assocTypeStr[];
+ static const TQString assocTypeStr[];
UMLRole * m_pRole[2];
Uml::Association_Type m_AssocType;
- QString m_Name;
+ TQString m_Name;
bool m_bOldLoadMode;
};
@@ -200,14 +200,14 @@ public:
/**
- * Convert Changeability_Type value into QString representation.
+ * Convert Changeability_Type value into TQString representation.
*
* @param type The Changeability_Type enum value to convert.